Me - 当前用户
=============

..  topic:: 注意

    请先查看 :doc:`说明 <intro>` 了解一下知乎相关类的文档的阅读方法。
    否则你会看不懂下面的东西的…………

..  automodule:: zhihu_oauth.zhcls.me
    :members:
    :undoc-members:
    :special-members: __init__
